@@ -3,47 +3,34 @@
 #TODO: """DocString if there is one"""
 
 import functools
-import io
-import os
 import textwrap
 import time
 
-from PyQt5 import uic
-from PyQt5.QtCore import pyqtProperty, QFile, QFileInfo, QTextStream
-from PyQt5.QtGui import QColor
-from PyQt5.QtWidgets import QLabel, QHBoxLayout, QWidget
+from PyQt5 import QtWidgets
+
+import epyqlib.parameteredit_ui
+import epyqlib.utils.qt
+
 
 # See file COPYING in this source tree
 __copyright__ = 'Copyright 2016, EPC Power Corp.'
 __license__ = 'GPLv2+'
 
 
-class ParameterEdit(QWidget):
+class ParameterEdit(QtWidgets.QWidget):
     def __init__(self, parent=None, in_designer=False, edit=None, nv=None,
                  dialog=None, esc_action=None):
-        QWidget.__init__(self, parent=parent)
+        super().__init__(parent=parent)
 
         self.in_designer = in_designer
 
-        ui = os.path.join(QFileInfo.absolutePath(QFileInfo(__file__)),
-                          'parameteredit.ui')
-
-        # TODO: CAMPid 9549757292917394095482739548437597676742
-        if not QFileInfo(ui).isAbsolute():
-            ui_file = os.path.join(
-                QFileInfo.absolutePath(QFileInfo(__file__)), ui)
-        else:
-            ui_file = ui
-        ui_file = QFile(ui_file)
-        ui_file.open(QFile.ReadOnly | QFile.Text)
-        ts = QTextStream(ui_file)
-        sio = io.StringIO(ts.readAll())
-        self.ui = uic.loadUi(sio, self)
-
         self._edit = edit
         self._dialog = dialog
         self.nv = nv
 
+        self.ui = epyqlib.parameteredit_ui.Ui_Form()
+        self.ui.setupUi(self)
+
         self.ui.to_device.set_signal(self.nv)
         self.nv.status_signal.value_changed.connect(self.nv.value_changed)
 
