@@ -1,5 +1,6 @@
 import contextlib
 import itertools
+import math
 import uuid
 
 import attr
@@ -250,21 +251,16 @@ class Parameter(epyqlib.treenode.TreeNode):
 
     @epyqlib.attrsmodel.check_children
     def check(self, result, models):
-        results = []
-
-        print()
         try:
             models.sunspec.root.nodes_by_attribute(
                 attribute_value=self.uuid,
                 attribute_name='parameter_uuid',
             )
         except epyqlib.treenode.NotFoundError:
-            results.append('No linked SunSpec data point found')
-
-        for r in results:
             result.append_child(epyqlib.checkresultmodel.Result(
                 node=self,
-                message=r,
+                severity=epyqlib.checkresultmodel.ResultSeverity.information,
+                message='No linked SunSpec data point found',
             ))
 
         return result
@@ -583,6 +579,7 @@ class Array(epyqlib.treenode.TreeNode):
             field=marshmallow.fields.String(),
         ),
     )
+    abbreviation = create_abbreviation_attribute()
     length = attr.ib(
         default=1,
         converter=int,
@@ -644,10 +641,14 @@ class Array(epyqlib.treenode.TreeNode):
                 for row in range(len(self.children) - 1, value - 1, - 1):
                     self.remove_child(row=row)
             elif 1 <= len(self.children) < value:
-                for _ in range(value - len(self.children)):
+                places = math.ceil(math.log10(value + 1))
+                for index in range(len(self.children), value):
                     original = self.children[0]
                     type_ = self.element_types[type(original)]
-                    self.append_child(type_(original=original))
+                    new_child = type_(original=original)
+                    new_child.name = f'_{(index + 1):0{places}}'
+                    new_child.abbreviation = f'{self.abbreviation}{index + 1}'
+                    self.append_child(new_child)
 
         epyqlib.utils.qt.pyqtify_set(self, 'length', value)
 
@@ -875,6 +876,9 @@ class TableArrayElement(epyqlib.treenode.TreeNode):
     def update(self):
         sort_multiselect(self)
 
+    def uses_interface_item(self):
+        return True
+
     can_delete = epyqlib.attrsmodel.childless_can_delete
     remove_old_on_drop = epyqlib.attrsmodel.default_remove_old_on_drop
     child_from = epyqlib.attrsmodel.default_child_from
@@ -1638,7 +1642,13 @@ def merge(name, *types):
 
 columns = epyqlib.attrsmodel.columns(
     merge('name', *types.types.values()),
-    merge('abbreviation', Parameter, ArrayParameterElement, TableArrayElement),
+    merge(
+        'abbreviation',
+        Parameter,
+        ArrayParameterElement,
+        TableArrayElement,
+        Array,
+    ),
     (
         merge('type_name', Parameter, Group)
         + merge('type', SunSpecEnumerator)
